@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for Fedora 12's 2.6.31 kernel.
+# This is a kernel build script for Fedora 11's 2.6.30 kernel.
 #
 
 die () {
@@ -10,33 +10,33 @@ die () {
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-2.6.31.6-166.fc12.src.rpm ]
+if [ ! -r kernel-2.6.30.10-105.2.23.fc11.src.rpm ]
 then
-    wget http://ftp.riken.jp/Linux/fedora/updates/12/SRPMS/kernel-2.6.31.6-166.fc12.src.rpm || die "Can't download source package."
+    wget http://ftp.riken.jp/Linux/fedora/updates/11/SRPMS/kernel-2.6.30.10-105.2.23.fc11.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-2.6.31.6-166.fc12.src.rpm || die "Can't install source package."
+rpm -ivh kernel-2.6.30.10-105.2.23.fc11.src.rpm || die "Can't install source package."
 
 cd /root/rpmbuild/SOURCES/ || die "Can't chdir to /root/rpmbuild/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.1-20091220.tar.gz ]
+if [ ! -r ccs-patch-1.7.1-20100214.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/43375/ccs-patch-1.7.1-20091220.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/43375/ccs-patch-1.7.1-20100214.tar.gz || die "Can't download patch."
 fi
 
 cd /root/rpmbuild/SPECS/ || die "Can't chdir to /root/rpmbuild/SPECS/ ."
 cp -p kernel.spec ccs-kernel.spec || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- ccs-kernel.spec	2009-12-09 23:39:16.000000000 +0900
-+++ ccs-kernel.spec	2009-12-11 05:55:46.768877116 +0900
+--- ccs-kernel.spec	2010-02-11 15:43:46.000000000 +0900
++++ ccs-kernel.spec	2010-02-13 17:41:56.903388784 +0900
 @@ -15,7 +15,7 @@
  # that the kernel isn't the stock distribution kernel, for example,
  # by setting the define to ".local" or ".bz123456"
  #
 -# % define buildid .local
-+%define buildid _tomoyo_1.7.1p1
++%define buildid _tomoyo_1.7.1p2
  
  # fedora_build defines which build revision of this kernel version we're
  # building. Rather than incrementing forever, as with the prior versioning
-@@ -409,6 +409,11 @@
+@@ -393,6 +393,11 @@
  # to versions below the minimum
  #
  
@@ -48,16 +48,16 @@ patch << "EOF" || die "Can't patch spec file."
  #
  # First the general kernel 2.6 required versions as per
  # Documentation/Changes
-@@ -444,7 +449,7 @@
+@@ -428,7 +433,7 @@
  # Packages that need to be installed before the kernel is, because the %post
  # scripts use them.
  #
--%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, kernel-firmware >= %{rpmversion}-%{pkg_release}, grubby >= 7.0.4-1
-+%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, grubby >= 7.0.4-1
- %if %{with_dracut}
- %define initrd_prereq  dracut >= 001-7
- %else
-@@ -480,7 +485,7 @@
+-%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.61-1, kernel-firmware >= %{rpmversion}-%{pkg_release}, /sbin/new-kernel-pkg
++%define kernel_prereq  fileutils, module-init-tools, initscripts >= 8.11.1-1, mkinitrd >= 6.0.61-1, /sbin/new-kernel-pkg
+ 
+ #
+ # This macro does requires, provides, conflicts, obsoletes for a kernel package.
+@@ -456,7 +461,7 @@
  AutoProv: yes\
  %{nil}
  
@@ -66,7 +66,7 @@ patch << "EOF" || die "Can't patch spec file."
  Group: System Environment/Kernel
  License: GPLv2
  URL: http://www.kernel.org/
-@@ -917,7 +922,7 @@
+@@ -993,7 +998,7 @@
  Provides: kernel-devel-uname-r = %{KVERREL}%{?1:.%{1}}\
  AutoReqProv: no\
  Requires(pre): /usr/bin/find\
@@ -75,18 +75,18 @@ patch << "EOF" || die "Can't patch spec file."
  This package provides kernel headers and makefiles sufficient to build modules\
  against the %{?2:%{2} }kernel package.\
  %{nil}
-@@ -1526,6 +1531,10 @@
+@@ -1692,6 +1697,10 @@
  
  # END OF PATCH APPLICATIONS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.1-20091220.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.31-fedora-12.diff
++tar -zxf %_sourcedir/ccs-patch-1.7.1-20100214.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.30-fedora-11.diff
 +
  %endif
  
  # Any further pre-build tree manipulations happen here.
-@@ -1552,6 +1561,9 @@
+@@ -1718,6 +1727,9 @@
  for i in *.config
  do
    mv $i .config
