@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 11.0's 2.6.25 kernel.
+# This is a kernel build script for openSUSE 10.3's 2.6.22 kernel.
 #
 
 die () {
@@ -13,9 +13,9 @@ cd /usr/lib/rpm/ || die "Can't chdir to /usr/lib/rpm/ ."
 if ! grep -q ccs-kernel find-supplements.ksyms
 then
 	patch << "EOF" || die "Can't patch find-supplements.ksyms ."
---- find-supplements.ksyms	2008-05-22 10:02:00.000000000 +0900
-+++ find-supplements.ksyms	2008-06-11 11:04:06.000000000 +0900
-@@ -7,6 +7,7 @@
+--- find-supplements.ksyms	2008-04-16 14:18:13.000000000 +0900
++++ find-supplements.ksyms	2008-04-16 14:19:06.000000000 +0900
+@@ -6,6 +6,7 @@
  case "$1" in
  kernel-module-*)    ;; # Fedora kernel module package names start with
  		       # kernel-module.
@@ -60,37 +60,37 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-2.6.25.20-0.5.src.rpm ]
+if [ ! -r kernel-source-2.6.22.19-0.4.src.rpm ]
 then
-    wget http://download.opensuse.org/update/11.0/rpm/src/kernel-source-2.6.25.20-0.5.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/10.3/rpm/src/kernel-source-2.6.22.19-0.4.src.rpm || die "Can't download source package."
 fi
-rpm -ivh kernel-source-2.6.25.20-0.5.src.rpm || die "Can't install source package."
+rpm -ivh kernel-source-2.6.22.19-0.4.src.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.7.1-20091220.tar.gz ]
+if [ ! -r ccs-patch-1.7.1-20100214.tar.gz ]
 then
-    wget http://osdn.dl.sourceforge.jp/tomoyo/43375/ccs-patch-1.7.1-20091220.tar.gz || die "Can't download patch."
+    wget http://osdn.dl.sourceforge.jp/tomoyo/43375/ccs-patch-1.7.1-20100214.tar.gz || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 cp -p /usr/src/packages/SOURCES/kernel-default.spec . || die "Can't copy spec file."
 patch << "EOF" || die "Can't patch spec file."
---- kernel-default.spec	2009-06-02 08:59:34.000000000 +0900
-+++ kernel-default.spec	2009-06-09 12:06:33.000000000 +0900
-@@ -47,10 +47,10 @@
- %define build_nomodules 1
+--- kernel-default.spec	2009-05-28 19:02:43.000000000 +0900
++++ kernel-default.spec	2009-06-09 09:45:35.000000000 +0900
+@@ -44,10 +44,10 @@
+ %define build_vanilla 1
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel for both Uniprocessor and Multiprocessor Systems
- Version:        2.6.25.20
--Release: 0.5
-+Release: 0.5_tomoyo_1.7.1p1
+ Version:        2.6.22.19
+-Release: 0.4
++Release: 0.4_tomoyo_1.7.1p2
  License:        GPL v2 or later
  Group:          System/Kernel
- Url:            http://www.kernel.org/
-@@ -213,7 +213,7 @@
+ AutoReqProv:    on
+@@ -198,7 +198,7 @@
  %define tolerate_unknown_new_config_options 0
  # kABI change tolerance (default in maintenance should be 4, 6, 8 or 15,
  # 31 is the maximum; see scripts/kabi-checks)
@@ -99,13 +99,13 @@ patch << "EOF" || die "Can't patch spec file."
  
  %description
  The standard kernel for both uniprocessor and multiprocessor systems.
-@@ -315,6 +315,10 @@
+@@ -289,6 +289,10 @@
  %build
  source .rpm-defs
- cd linux-2.6.25
+ cd linux-2.6.22
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.7.1-20091220.tar.gz
-+patch -sp1 < patches/ccs-patch-2.6.25-suse-11.0.diff
++tar -zxf %_sourcedir/ccs-patch-1.7.1-20100214.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.22-suse-10.3.diff
 +cat config.ccs >> .config
  cp .config .config.orig
  %if %{tolerate_unknown_new_config_options}
