@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2005-2009  NTT DATA CORPORATION
  *
- * Version: 1.7.0   2009/09/03
+ * Version: 1.7.1+   2009/12/20
  *
  * This file is applicable to both 2.4.30 and 2.6.11 and later.
  * See README.ccs for ChangeLog.
@@ -393,6 +393,7 @@ bool ccs_tokenize(char *buffer, char *w[], size_t size)
 
 /**
  * ccs_is_correct_path - Validate a pathname.
+ *
  * @filename:     The pathname to check.
  * @start_type:   Should the pathname start with '/'?
  *                1 = must / -1 = must not / 0 = don't care
@@ -407,6 +408,8 @@ bool ccs_tokenize(char *buffer, char *w[], size_t size)
 bool ccs_is_correct_path(const char *filename, const s8 start_type,
 			 const s8 pattern_type, const s8 end_type)
 {
+	const char *const start = filename;
+	bool in_repetition = false;
 	bool contains_pattern = false;
 	unsigned char c;
 	unsigned char d;
@@ -453,6 +456,22 @@ bool ccs_is_correct_path(const char *filename, const s8 start_type,
 					break; /* Must not contain pattern */
 				contains_pattern = true;
 				continue;
+			case '{':   /* "/\{" */
+				if (filename - 3 < start ||
+				    *(filename - 3) != '/')
+					break;
+				if (pattern_type == -1)
+					break; /* Must not contain pattern */
+				contains_pattern = true;
+				in_repetition = true;
+				continue;
+			case '}':   /* "\}/" */
+				if (*filename != '/')
+					break;
+				if (!in_repetition)
+					break;
+				in_repetition = false;
+				continue;
 			case '0':   /* "\ooo" */
 			case '1':
 			case '2':
@@ -468,6 +487,8 @@ bool ccs_is_correct_path(const char *filename, const s8 start_type,
 					continue; /* pattern is not \000 */
 			}
 			goto out;
+		} else if (in_repetition && c == '/') {
+			goto out;
 		} else if (c <= ' ' || c >= 127) {
 			goto out;
 		}
@@ -476,6 +497,8 @@ bool ccs_is_correct_path(const char *filename, const s8 start_type,
 		if (!contains_pattern)
 			goto out;
 	}
+	if (in_repetition)
+		goto out;
 	return true;
  out:
 	return false;
@@ -483,6 +506,7 @@ bool ccs_is_correct_path(const char *filename, const s8 start_type,
 
 /**
  * ccs_is_correct_domain - Check whether the given domainname follows the naming rules.
+ *
  * @domainname:   The domainname to check.
  *
  * Returns true if @domainname follows the naming rules, false otherwise.
@@ -573,32 +597,6 @@ struct ccs_domain_info *ccs_find_domain(const char *domainname)
 	return NULL;
 }
 
-/**
- * ccs_path_depth - Evaluate the number of '/' in a string.
- *
- * @pathname: The string to evaluate.
- *
- * Returns path depth of the string.
- *
- * I score 2 for each of the '/' in the @pathname
- * and score 1 if the @pathname ends with '/'.
- */
-static int ccs_path_depth(const char *pathname)
-{
-	int i = 0;
-	if (pathname) {
-		const char *ep = pathname + strlen(pathname);
-		if (pathname < ep--) {
-			if (*ep != '/')
-				i++;
-			while (pathname <= ep)
-				if (*ep-- == '/')
-					i += 2;
-		}
-	}
-	return i;
-}
-
 /**
  * ccs_const_part_length - Evaluate the initial length without a pattern in a token.
  *
@@ -659,12 +657,10 @@ void ccs_fill_path_info(struct ccs_path_info *ptr)
 	ptr->is_dir = len && (name[len - 1] == '/');
 	ptr->is_patterned = (ptr->const_len < len);
 	ptr->hash = full_name_hash(name, len);
-	ptr->depth = ccs_path_depth(name);
 }
 
 /**
- * ccs_file_matches_pattern2 - Pattern matching without '/' character
- * and "\-" pattern.
+ * ccs_file_matches_pattern2 - Pattern matching without '/' character and "\-" pattern.
  *
  * @filename:     The start of string to check.
  * @filename_end: The end of string to check.
@@ -725,7 +721,7 @@ static bool ccs_file_matches_pattern2(const char *filename,
 		case '2':
 		case '3':
 			if (c == '\\' && ccs_is_byte_range(filename + 1)
-			    && strncmp(filename + 1, pattern, 3) == 0) {
+			    && !strncmp(filename + 1, pattern, 3)) {
 				filename += 3;
 				pattern += 2;
 				break;
@@ -820,55 +816,26 @@ static bool ccs_file_matches_pattern(const char *filename,
 }
 
 /**
- * ccs_path_matches_pattern - Check whether the given filename matches the given pattern.
- * @filename: The filename to check.
- * @pattern:  The pattern to compare.
+ * ccs_path_matches_pattern2 - Do pathname pattern matching.
  *
- * Returns true if matches, false otherwise.
+ * @f: The start of string to check.
+ * @p: The start of pattern to compare.
  *
- * The following patterns are available.
- *   \\     \ itself.
- *   \ooo   Octal representation of a byte.
- *   \*     More than or equals to 0 character other than '/'.
- *   \@     More than or equals to 0 character other than '/' or '.'.
- *   \?     1 byte character other than '/'.
- *   \$     More than or equals to 1 decimal digit.
- *   \+     1 decimal digit.
- *   \X     More than or equals to 1 hexadecimal digit.
- *   \x     1 hexadecimal digit.
- *   \A     More than or equals to 1 alphabet character.
- *   \a     1 alphabet character.
- *   \-     Subtraction operator.
+ * Returns true if @f matches @p, false otherwise.
  */
-bool ccs_path_matches_pattern(const struct ccs_path_info *filename,
-			      const struct ccs_path_info *pattern)
+static bool ccs_path_matches_pattern2(const char *f, const char *p)
 {
-	/*
-	  if (!filename || !pattern)
-	  return false;
-	*/
-	const char *f = filename->name;
-	const char *p = pattern->name;
-	const int len = pattern->const_len;
-	/* If @pattern doesn't contain pattern, I can use strcmp(). */
-	if (!pattern->is_patterned)
-		return !ccs_pathcmp(filename, pattern);
-	/* Don't compare if the number of '/' differs. */
-	if (filename->depth != pattern->depth)
-		return false;
-	/* Compare the initial length without patterns. */
-	if (strncmp(f, p, len))
-		return false;
-	f += len;
-	p += len;
-	/* Main loop. Compare each directory component. */
+	const char *f_delimiter;
+	const char *p_delimiter;
 	while (*f && *p) {
-		const char *f_delimiter = strchr(f, '/');
-		const char *p_delimiter = strchr(p, '/');
+		f_delimiter = strchr(f, '/');
 		if (!f_delimiter)
 			f_delimiter = f + strlen(f);
+		p_delimiter = strchr(p, '/');
 		if (!p_delimiter)
 			p_delimiter = p + strlen(p);
+		if (*p == '\\' && *(p + 1) == '{')
+			goto recursive;
 		if (!ccs_file_matches_pattern(f, f_delimiter, p, p_delimiter))
 			return false;
 		f = f_delimiter;
@@ -883,6 +850,78 @@ bool ccs_path_matches_pattern(const struct ccs_path_info *filename,
 	       (*(p + 1) == '*' || *(p + 1) == '@'))
 		p += 2;
 	return !*f && !*p;
+ recursive:
+	/*
+	 * The "\{" pattern is permitted only after '/' character.
+	 * This guarantees that below "*(p - 1)" is safe.
+	 * Also, the "\}" pattern is permitted only before '/' character
+	 * so that "\{" + "\}" pair will not break the "\-" operator.
+	 */
+	if (*(p - 1) != '/' || p_delimiter <= p + 3 || *p_delimiter != '/' ||
+	    *(p_delimiter - 1) != '}' || *(p_delimiter - 2) != '\\')
+		return false; /* Bad pattern. */
+	do {
+		/* Compare current component with pattern. */
+		if (!ccs_file_matches_pattern(f, f_delimiter, p + 2,
+					      p_delimiter - 2))
+			break;
+		/* Proceed to next component. */
+		f = f_delimiter;
+		if (!*f)
+			break;
+		f++;
+		/* Continue comparison. */
+		if (ccs_path_matches_pattern2(f, p_delimiter + 1))
+			return true;
+		f_delimiter = strchr(f, '/');
+	} while (f_delimiter);
+	return false; /* Not matched. */
+}
+
+/**
+ * ccs_path_matches_pattern - Check whether the given filename matches the given pattern.
+ *
+ * @filename: The filename to check.
+ * @pattern:  The pattern to compare.
+ *
+ * Returns true if matches, false otherwise.
+ *
+ * The following patterns are available.
+ *   \\     \ itself.
+ *   \ooo   Octal representation of a byte.
+ *   \*     Zero or more repetitions of characters other than '/'.
+ *   \@     Zero or more repetitions of characters other than '/' or '.'.
+ *   \?     1 byte character other than '/'.
+ *   \$     One or more repetitions of decimal digits.
+ *   \+     1 decimal digit.
+ *   \X     One or more repetitions of hexadecimal digits.
+ *   \x     1 hexadecimal digit.
+ *   \A     One or more repetitions of alphabet characters.
+ *   \a     1 alphabet character.
+ *
+ *   \-     Subtraction operator.
+ *
+ *   /\{dir\}/   '/' + 'One or more repetitions of dir/' (e.g. /dir/ /dir/dir/
+ *               /dir/dir/dir/ ).
+ */
+bool ccs_path_matches_pattern(const struct ccs_path_info *filename,
+			      const struct ccs_path_info *pattern)
+{
+	const char *f = filename->name;
+	const char *p = pattern->name;
+	const int len = pattern->const_len;
+	/* If @pattern doesn't contain pattern, I can use strcmp(). */
+	if (!pattern->is_patterned)
+		return !ccs_pathcmp(filename, pattern);
+	/* Don't compare directory and non-directory. */
+	if (filename->is_dir != pattern->is_dir)
+		return false;
+	/* Compare the initial length without patterns. */
+	if (strncmp(f, p, len))
+		return false;
+	f += len;
+	p += len;
+	return ccs_path_matches_pattern2(f, p);
 }
 
 /**
@@ -922,7 +961,7 @@ const char *ccs_get_exe(void)
  *
  * @profile:    Profile number.
  * @index:      Index number of functionality.
- * @is_granted: True if granted log, false otehrwise.
+ * @is_granted: True if granted log, false otherwise.
  *
  * Returns mode.
  */
@@ -1104,11 +1143,9 @@ bool ccs_domain_quota_ok(struct ccs_request_info *r)
 					count++;
 			break;
 		case CCS_TYPE_PATH_NUMBER3_ACL:
-			perm = container_of(ptr,
-					    struct ccs_path_number3_acl,
+			perm = container_of(ptr, struct ccs_path_number3_acl,
 					    head)->perm;
-			for (i = 0; i < CCS_MAX_PATH_NUMBER3_OPERATION;
-			     i++)
+			for (i = 0; i < CCS_MAX_PATH_NUMBER3_OPERATION; i++)
 				if (perm & (1 << i))
 					count++;
 			break;
@@ -1127,6 +1164,7 @@ bool ccs_domain_quota_ok(struct ccs_request_info *r)
 		return true;
 	if (!domain->quota_warned) {
 		domain->quota_warned = true;
+		ccs_write_audit_log(false, r, CCS_KEYWORD_QUOTA_EXCEEDED "\n");
 		printk(KERN_WARNING "WARNING: "
 		       "Domain '%s' has so many ACLs to hold. "
 		       "Stopped learning mode.\n", domain->domainname->name);
